@@ -297,7 +297,7 @@ class MongodbHelper(BaseSqlHelper):
                 column, op = order
                 order_item.setdefault(column, 1 if op == "ASC" else -1)
             aggregate.append({"$sort": order_item})
-        if condition_wrapper.column != "*":
+        if condition_wrapper.column != "*" or condition_wrapper.column:
             aggregate.append({"$project": condition_wrapper.column})
         return aggregate
 
