@@ -7,10 +7,10 @@ from lesscode.db.base_connection_pool import BaseConnectionPool
 
 
 class MongodbPool(BaseConnectionPool):
-
     """
     mongodb 数据库链接创建类
     """
+
     def create_pool(self):
         print("mongodb create_pool")
         """
@@ -21,7 +21,9 @@ class MongodbPool(BaseConnectionPool):
         info = self.conn_info
         if info.async_enable:
             import motor
-            conn_info_string = f"mongodb://{info.user}:{info.password}@{info.host}:{info.port}"
+            host_str = info.host.split(",")
+            hosts = ",".join([f"{host}:{info.port}" for host in host_str])
+            conn_info_string = f"mongodb://{info.user}:{info.password}@{hosts}"
             if info.params:
                 if info.params == "LDAP":
                     conn_info_string += "/?authMechanism=PLAIN"
