@@ -195,6 +195,7 @@ class BaseHandler(RequestHandler):
             self.set_header("Access-Control-Allow-Origin", origin)
         else:
             self.set_header("Access-Control-Allow-Origin", "*")
+        self.set_header("requestID", self.request.headers.get("requestID", ""))
         self.set_header("Access-Control-Allow-Headers", "x-requested-with,Authorization,Can-read-cache")
         self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
         self.set_header("Access-Control-Expose-Headers", "Access-Token")
@@ -267,9 +268,10 @@ class User:
     """
     用户对象类
     """
+
     def __init__(self):
         # '账号id',
-        self.id =None
+        self.id = None
         # 用户名
         self.username = None
         # '密码',
@@ -284,7 +286,8 @@ class User:
         self.org_id = None
         # '1正常（激活）；2未激活（管理员新增，首次登录需要改密码）； 3锁定（登录错误次数超限，锁定时长可配置）； 4休眠（长期未登录（字段，时长可配置），定时） 5禁用-账号失效；
         self.account_status = None
-
+        # 角色id集合
+        self.roleIds = None
 
 
 # 解析param
